//
//  YHCertificateResourceUploadVC.swift
//  galaxy
//
//  Created by edy on 2024/3/13.
//  Copyright © 2024 https://www.galaxy-immi.com. All rights reserved.
//

import UIKit
import JXSegmentedView
import UniformTypeIdentifiers
import IQKeyboardManagerSwift
import SwifterSwift

class YHCertificateListVC: YHBaseViewController {

    var orderId : Int?
    var status: YHCertificateUploadStatus = .all
    var items:[YHSupplementInfo] = []
    var viewModel: YHCertificateViewModel = YHCertificateViewModel()
    var categoryInfo: YHCategoryData!
    lazy var previewFileTool:YHFilePreviewTool = {
       let tool = YHFilePreviewTool(targetVC: self)
       return tool
    }()
    
    lazy var tableView: UITableView = {
        
        let tableView = UITableView(frame:.zero, style:.grouped)

        if #available(iOS 11.0, *) {
            tableView.contentInsetAdjustmentBehavior = .never
        }
        tableView.estimatedSectionHeaderHeight = 14.0
        tableView.estimatedSectionFooterHeight = 1.0
        tableView.showsVerticalScrollIndicator = false
        tableView.separatorStyle = .none
        tableView.delegate = self
        tableView.dataSource = self
        tableView.backgroundColor = UIColor(hexString:"#F8F8F8")
        tableView.register(UITableViewCell.self, forCellReuseIdentifier: "UITableViewCell")
        tableView.register(YHCertificateInfoCell.self, forCellReuseIdentifier: YHCertificateInfoCell.cellReuseIdentifier)
        tableView.backgroundView = emptyDataTipsView
        return tableView
    }()
    
    lazy var emptyDataTipsView: YHEmptyDataView = {
        let view = YHEmptyDataView.createView("没有找到相关资料哦~", kEmptyCommonBgName)
        view.topMargin = 130
        view.isHidden = false
        return view
    }()
    
    override func viewDidLoad() {
        super.viewDidLoad()
        self.view.backgroundColor = .white
        self.gk_navigationBar.isHidden = true
        createUI()
        requestList(status: status)
    }
    
    func createUI() {
        view.addSubview(tableView)
        tableView.snp.makeConstraints { make in
            make.top.left.right.equalToSuperview()
            make.height.equalTo(KScreenHeight - k_Height_NavigationtBarAndStatuBar - YHCertificateListContainerVC.segmentHeight)
        }
    }
}

extension YHCertificateListVC: UITableViewDelegate, UITableViewDataSource {
    
    func numberOfSections(in tableView: UITableView) -> Int {
        return items.count
    }

    func tableView(_ tableView: UITableView, numberOfRowsInSection section: Int) -> Int {
        return 1
    }
    
    func tableView(_ tableView: UITableView, cellForRowAt indexPath: IndexPath) -> UITableViewCell {
        
        let cell = tableView.dequeueReusableCell(withIdentifier: YHCertificateInfoCell.cellReuseIdentifier, for: indexPath) as! YHCertificateInfoCell
        
        if 0 <= indexPath.section && indexPath.section < items.count {
            let item = items[indexPath.section]
            cell.updateModel(item)
            cell.templateBlock = {
                [weak self] in
                guard let self = self else { return }
                let view = YHCertificateTemplateSheetView.templateView(item.templateInfo)
                view.scanTemplateBlock = {
                    [weak self] path in
                    guard let self = self else { return }
                    if let url = path?.url, !url.isEmpty {
                        print(url)
                        self.previewFileTool.openXLSXRemoteFile(urlString:url, fileName:"预览")
                    }
                }
                view.show()
            }
        }
        return cell
    }
    
    func tableView(_ tableView: UITableView, heightForRowAt indexPath: IndexPath) -> CGFloat {
        return UITableView.automaticDimension
    }
    
    func tableView(_ tableView: UITableView, didSelectRowAt indexPath: IndexPath) {
       
        if 0 <= indexPath.section && indexPath.section < items.count {
            let item = items[indexPath.section]
            
            if item.checkStatus == YHCertificateUploadStatus.preUpload.rawValue { // 待上传
                showUploadSheetView(item)
                return
            }
            // 非待上传的进入详情
            let vc = YHCertificateUploadContentListVC()
            vc.orderId = orderId
            vc.categoryInfo = categoryInfo
            vc.supplementInfo = item
            self.navigationController?.pushViewController(vc)
        }
    }

    private func tableView(_ tableView: UITableView, viewForHeaderInSection section: Int) -> CGFloat {
        return 14.0
    }
    
    private func tableView(_ tableView: UITableView, viewForFooterInSection section: Int) -> CGFloat {
        return 1.0
    }
    
    func tableView(_ tableView: UITableView, viewForFooterInSection section: Int) -> UIView? {
        
        return UIView()
    }
    
    func tableView(_ tableView: UITableView, viewForHeaderInSection section: Int) -> UIView? {
        
        return UIView()
    }
}

// MARK: - JXSegmentedListContainerViewListDelegate
extension YHCertificateListVC: JXSegmentedListContainerViewListDelegate {
    func listView() -> UIView {
        return view
    }
}

extension YHCertificateListVC {
    
    func requestList(status: YHCertificateUploadStatus, extra:[String:Any] = [:]) {
        
        /*
        // 状态
        "status_all": "",
        // 类型
        "template_cate_id": "",
        // 搜索
        "keywork": "",
         */
        
        var params:[String:Any] = [
                                    "order_id" : orderId ?? 0,
                                    "node": "1",
                                    "state": "1",
                                    "category_id": categoryInfo.categoryId,
                                    "supplement_ids": []]
        if !extra.isEmpty {
           params += extra
        }
        
        print(params)
        // state: 3:待上传 2:已驳回 1:已完成 0:审核中
        viewModel.getCertificateList(params: params) {
            
            [weak self] listInfo, error in
            guard let self = self else { return }
            
            items.removeAll()
            if let listInfo = listInfo {
                let arr = listInfo.supplementList
                var results: [YHSupplementInfo] = []
                if status == .all {
                    results.append(contentsOf:arr)
                } else {
                    for item in arr {
                        if item.checkStatus == status.rawValue {
                            results.append(item)
                        }
                    }
                }
                items.append(contentsOf: results)
            }
            // 数量统计
            NotificationCenter.default.post(name: countStatisticsNotify, object: [self.status: items.count])
            
            emptyDataTipsView.isHidden = items.count > 0
            self.tableView.reloadData()
            
            if let errorMsg = error?.errorMsg, errorMsg.count > 0 {
                YHHUD.flash(message: errorMsg, duration:3)
            }
        }
    }
    
    func uploadImage(_ img: UIImage, imageName:String, supplementInfo:YHSupplementInfo, callBack:((Bool)->())?)  {
        
        // 先OSS上传得到URL
        self.viewModel.uploadImage(img) {
            [weak self] url, error in
            guard let self = self else { return }
            if let url = url, !url.isEmpty {
                var suffix = "jpg"
                let suffixName = url.pathExtension.lowercased()
                if !suffixName.isEmpty {
                    suffix = suffixName
                }
                
                // 再调用业务接口
                let model = YHContentUrl()
                model.name = imageName
                model.url = url
                model.suffix = suffix
            
                self.viewModel.updateCertificateItem(supplementsId:supplementInfo.id, urlModel:model, operation: "add", rename: "") {
                    success, error in
                    self.requestList(status: self.status)
                    callBack?(success)
                }
                return
            }
            callBack?(false)
        }
    }
    
    func uploadFile(_ fileUrl:URL, supplementInfo:YHSupplementInfo, successBlock:(()->())?)  {
        if let fileData = try? Data(contentsOf: fileUrl) {
            // 将文件数据上传到服务器
            let size = String(format: "%.2fM", Double(fileData.count)/(1024.0 * 1024.0))
            print("\(size)")
            // 先OSS上传得到URL
            YHHUD.show(.progress(message: "上传中..."))
            self.viewModel.uploadFile(fileUrl.absoluteString) {
                [weak self] successUrl, error in
                guard let self = self else { return }
                
                YHHUD.hide()
                
                // 再调用业务接口
                if let successUrl = successUrl, !successUrl.isEmpty {
                    let fileName = successUrl.lastPathComponent
                    let suffixName = successUrl.pathExtension.lowercased()
                    let model = YHContentUrl()
                    model.name = fileName
                    model.url = successUrl
                    model.suffix = suffixName
                    YHHUD.show(.progress(message: "上传中..."))
                    self.viewModel.updateCertificateItem(supplementsId:supplementInfo.id, urlModel:model, operation: "add", rename: "") {
                        success, error in
                        YHHUD.hide()
                        self.requestList(status:self.status)
                        if success {
                            YHHUD.flash(message: "上传成功")
                        } else {
                            var msg = "上传失败"
                            if let errorMsg = error?.errorMsg, !errorMsg.isEmpty {
                                msg = errorMsg
                            }
                            YHHUD.flash(message:msg)
                        }
                        if success {
                            successBlock?()
                        }
                    }
                    return
                }
                var msg = "上传图片失败"
                if let errorMsg = error?.errorMsg, !errorMsg.isEmpty {
                    msg = errorMsg
                }
                YHHUD.flash(message: msg)

            }
        } else {
            YHHUD.flash(message: "识别文件失败")
        }
    }
    
    func showUploadSheetView(_ supplementInfo: YHSupplementInfo) {
                
        let sheetView = YHCertificateUploadSheetView.sheetView()
        sheetView.maxSelectCount = 9
         sheetView.uploadFilesBlock = {
            [weak self] fileUrl in
            guard let self = self else { return }
            print(fileUrl)
             uploadFile(fileUrl, supplementInfo: supplementInfo) {
                 // 待上传的进入详情
                 DispatchQueue.main.async {
                     let vc = YHCertificateUploadContentListVC()
                     vc.orderId = self.orderId
                     vc.categoryInfo = self.categoryInfo
                     vc.supplementInfo = supplementInfo
                     self.navigationController?.pushViewController(vc)
                 }
             }
        }
        sheetView.uploadImageBlock = {
            [weak self] imgArr in
            guard let self = self else { return }
            var successArr:[YHSelectImageItem] = []
            var failArr:[YHSelectImageItem] = []
            let group = DispatchGroup()

            YHHUD.show(.progress(message: "上传中..."))
            for item in imgArr {
                if let image = item.data {
                    group.enter()
                    uploadImage(image, imageName:item.name, supplementInfo: supplementInfo) {
                        success in
                        if success {
                            successArr.append(item)
                        } else {
                            failArr.append(item)
                        }
                        group.leave()
                    }
                }
            }
            
            // 等待所有任务完成
            group.notify(queue: .main) {
                YHHUD.hide()
                // 所有任务完成，回到主线程继续执行
                print("所有任务完成")
                if imgArr.count == successArr.count {
                    YHHUD.flash(message: "上传成功")
                    
                } else {
                    YHHUD.flash(message: "\(successArr.count)张照片上传成功\n\(failArr.count)张照片上传失败")
                }
                if successArr.count > 0 {
                    let vc = YHCertificateUploadContentListVC()
                    vc.orderId = self.orderId
                    vc.categoryInfo = self.categoryInfo
                    vc.supplementInfo = supplementInfo
                    self.navigationController?.pushViewController(vc)
                }
            }
        }
        sheetView.show()
    }
    
}
